@@ -14,7 +14,7 @@ Data::Chronicle::Reader - Provides reading from an efficient data storage for vo
 
 =cut
 
-our $VERSION = '0.18';    ## VERSION
+our $VERSION = '0.19';    ## VERSION
 
 =head1 DESCRIPTION
 
@@ -130,8 +130,8 @@ sub mget {
 
     my @keys = map { $_->[0] . '::' . $_->[1] } @$pairs;
 
-    my @cached_data = $self->cache_reader->mget(@keys);
-    return map { decode_json_utf8($_) if $_ } @cached_data;
+    my $cached_data = $self->cache_reader->mget(@keys);
+    return map { decode_json_utf8($_) if $_ } @$cached_data;
 }
 
 =head2 get_for
